@@ -101,12 +101,12 @@ impl<'r> EvalEnv<'r> {
         /*
             if let Some(n) = stacker::remaining_stack()
             {
-              if n < 64 * 1024 { panic!("Stack less than 64k call depth={}", self.call_depth) }
+              if n < 64 * 1024 { panic!("stack less than 64k call depth={}", self.call_depth) }
             }
             else
         */
         if self.call_depth > 500 {
-            panic!("Call depth limit of 500 reached");
+            panic!("call depth limit of 500 reached");
         }
         let save_bp = self.bp;
         self.bp = self.stack.len() - r.param_count;
@@ -182,7 +182,7 @@ impl<'r> EvalEnv<'r> {
             let next = if let Value::For(fs) = &self.stack[self.bp + info.for_id] {
                 fs.borrow_mut().data_source.next()
             } else {
-                panic!("Jump into FOR loop");
+                panic!("jump into FOR loop");
             };
             if let Some((pp, off)) = next {
                 let p = pp.borrow();
@@ -225,7 +225,7 @@ impl<'r> EvalEnv<'r> {
                 true
             }
         } else {
-            panic!("Jump into FOR loop");
+            panic!("jump into FOR loop");
         }
     }
 
@@ -597,7 +597,7 @@ impl<'r> EvalEnv<'r> {
             db.tables.borrow_mut().insert(name.clone(), nt);
             db.function_reset.set(true);
         } else {
-            panic!("Alter Table not found {}", name.str());
+            panic!("ALTER TABLE not found {}", name.str());
         }
     }
 } // impl EvalEnv
