@@ -1,4 +1,3 @@
-#![warn(missing_docs)]
 //! This crate (rustdb) implements a high-performance database written entirely in [Rust](https://www.rust-lang.org/).
 //!
 //! The SQL-like language is relatively minimal, and does not (currently) include features such as joins or views.
@@ -59,21 +58,25 @@
 //!# Features
 //!
 //! This crate supports the following cargo features:
+//! - `gentrans` : enables gentrans module.
+//! - `webtrans` : enables webtrans module.
 //! - `builtin` : Allows extra SQL builtin functions to be defined.
-//! - `max` : Exposes maximal interface, including all internal modules (default).
+//! - `max` : maximal interface, including internal modules.
 //! - `verify` : Allows database structure to be verified using builtin function VERIFYDB.
 //! - `pack` : Allows database pages to be packed using builtin function REPACKFILE.
 //!
+//! By default, all features are enabled.
+//!
 //!# General Design of Database
 //!
 //! SortedFile stores fixed size Records in a tree of Pages.
 //! SortedFile is used to implement:
 //!
-//! - Variable length values which are split into fragments - see bytes module - although up to 254 bytes can be stored inline.
+//! - Database Table storage. Each fixed size record has a 64-bit Id.
 //!
-//! - Database Table storage. Each record has a 64-bit Id.
+//! - Variable length values which are split into fragments, although up to 249 bytes can be stored in the fiexed size record.
 //!
-//! - Index storage ( an index record refers back to the main table ).
+//! - Index storage ( an index record refers back to the main table using the 64-bit Id ).
 //!
 //! When a page becomes too big, it is split into two pages.
 //!
@@ -101,13 +104,17 @@
 pub use crate::{
     atomfile::AtomicFile,
     builtin::standard_builtins,
-    gentrans::{GenTransaction, Part},
     init::INITSQL,
     pstore::{AccessPagedData, SharedPagedData},
     stg::{MemFile, SimpleFileStorage, Storage},
-    webtrans::WebTransaction,
 };
 
+#[cfg(feature = "gentrans")]
+pub use crate::gentrans::{GenTransaction, Part};
+
+#[cfg(feature = "webtrans")]
+pub use crate::webtrans::WebTransaction;
+
 #[cfg(feature = "builtin")]
 pub use crate::{
     builtin::check_types,
@@ -160,11 +167,11 @@ pub mod util;
 #[macro_use]
 mod util;
 
-// Modules that are always public.
-
+#[cfg(feature = "gentrans")]
 /// [GenTransaction] ( implementation of [Transaction] ).
 pub mod gentrans;
 
+#[cfg(feature = "webtrans")]
 /// [WebTransaction] ( alternative implementation of [Transaction] with http support ).
 pub mod webtrans;
 
@@ -262,12 +269,16 @@ pub mod value;
 #[cfg(not(feature = "builtin"))]
 mod value;
 
-// Private modules.
-
+#[cfg(feature = "max")]
 /// Structs that implement [CExp] trait.
+pub mod cexp;
+#[cfg(not(feature = "max"))]
 mod cexp;
 
+#[cfg(feature = "max")]
 /// Storage of variable length values : [ByteStorage].
+pub mod bytes;
+#[cfg(not(feature = "max"))]
 mod bytes;
 
 // End of modules.
@@ -308,7 +319,7 @@ pub struct Database {
     /// Cache of loaded Tables.
     pub tables: RefCell<HashMap<ObjRef, Rc<Table>>>,
     /// Cache of loaded Functions.
-    pub functions: RefCell<HashMap<ObjRef, FunctionPtr>>,
+    pub functions: RefCell<HashMap<ObjRef, Rc<Function>>>,
 
     /// Last id generated by INSERT.
     pub lastid: Cell<i64>,
@@ -527,7 +538,7 @@ GO
     }
 
     /// Get the named function.
-    fn get_function(self: &DB, name: &ObjRef) -> Option<FunctionPtr> {
+    fn get_function(self: &DB, name: &ObjRef) -> Option<Rc<Function>> {
         if let Some(f) = self.functions.borrow().get(name) {
             return Some(f.clone());
         }
@@ -727,7 +738,7 @@ pub trait Transaction: Any {
     }
 }
 
-/// Query where output is printed to console (used for initialisation ).
+/// [Transaction] where output is printed to console (used for initialisation ).
 struct DummyTransaction {}
 impl Transaction for DummyTransaction {
     fn selected(&mut self, _values: &[Value]) {}
