@@ -17,10 +17,10 @@ pub type PagePtr = Rc<RefCell<Page>>;
 */
 
 /// = 3. Size of Balance,Left,Right in a Node ( 2 + 2 x 11 = 24 bits = 3 bytes ).
-pub const NODE_OVERHEAD: usize = 3;
+const NODE_OVERHEAD: usize = 3;
 
 /// = 8. 45 bits ( 1 + 4 x 11 ) needs 6 bytes, but use 8.
-pub const NODE_BASE: usize = 8;
+const NODE_BASE: usize = 8;
 
 /// = 6. Number of bytes used to store a page number.
 const PAGE_ID_SIZE: usize = 6;
@@ -197,7 +197,7 @@ impl Page {
         if inserted != self.next_alloc() {
             self.set_record(inserted, r);
         } else {
-            panic!("Duplicate key");
+            panic!("duplicate key");
         }
     }
 
