@@ -57,6 +57,18 @@ pub fn iget(data: &[u8], off: usize, n: usize) -> i64 {
     x as i64
 }
 
+/// Store signed value of n bytes to data ( with overflow check ).
+pub fn iset(data: &mut [u8], off: usize, val: i64, n: usize) {
+    if n < 8 {
+        let chk = val + (1 << ((n * 8) - 1));
+        if chk < 0 || chk >= (1 << (n * 8)) {
+            panic!("overflow storing value {} in {} bytes", val, n);
+        }
+    }
+    let bytes = val.to_le_bytes();
+    data[off..off + n].copy_from_slice(&bytes[0..n]);
+}
+
 /// Store unsigned value of n bytes to data.
 pub fn set(data: &mut [u8], off: usize, val: u64, n: usize) {
     let bytes = val.to_le_bytes();
